==> settingsd-0.8.4.tar.gz: settingsd-0.8.4/settingsd/extras/django.py <==
# encoding: utf8
"""
Descriptors for Django
"""

from __future__ import absolute_import
from __future__ import print_function

from .. import utils


# TODO: should probably call super(...) somehow?
def fallback_to_defaults(settings, key):
    from django.apps import apps
    from django.conf import settings as djsettings

    if not djsettings.configured:
        # this is __getattr__ usually, so use super(...)
        # to avoid recursion on SETTINGSD_NAMESPACE
        supr = super(settings.__class__, settings)
        ns = utils.namespace(supr)
        djsettings.configure(ns)
    if not apps.ready:
        import django
        django.setup()

    attr = getattr(djsettings, key)
    return attr


class LocateApps(object):
    """
    Proxies settings.app directly to django.apps
    """

    def __init__(self, app=None):
        self.__app = app

    def __getattr__(self, key):
        from django.apps import apps
        if self.__app:
            attr = apps.get_model(self.__app.label, key)
        else:
            conf = apps.get_app_config(key)
            attr = self.__class__(app=conf)
        # cache attr lookup
        setattr(self, key, attr)
        return attr

    def __dir__(self):
        from django.apps import apps
        if self.__app:
            # prefer object_name over model_name to match ClassNaming
            attrs = [
                model._meta.object_name
                for model in self.__app.get_models()
                if not model._meta.proxy
                ]
        else:
            attrs = [
                app.label
                for app in apps.get_app_configs()
                ]
        return attrs


class ConfigureApps(object):

    def __get__(self, settings, owner):
        if settings is None:
            return self

        from django.apps import apps
        from django.conf import settings as djsettings

        if not djsettings.configured:
            ns = utils.namespace(settings)
            djsettings.configure(ns)
        if not apps.ready:
            django.setup()

        return LocateApps()

    def __set__(self, settings, value):
        raise AttributeError("can't set attribute")

==> settingsd-0.8.5.tar.gz: settingsd-0.8.5/settingsd/extras/django.py <==
# encoding: utf8
"""
Descriptors for Django
"""

from __future__ import absolute_import
from __future__ import print_function

from .. import utils


# TODO: should probably call super(...) somehow?
def fallback_to_defaults(settings, key):
    from django.apps import apps
    from django.conf import settings as djsettings

    if not key.isupper() or key.startswith('SETTINGSD_'):
        # FIXME: need to call super(...) first somehow
        raise AttributeError(key)

    if not djsettings.configured:
        # this is __getattr__ usually, so use super(...)
        # to avoid recursion on SETTINGSD_NAMESPACE
        supr = super(settings.__class__, settings)
        ns = utils.namespace(supr)
        djsettings.configure(**ns)

    attr = getattr(djsettings, key)
    return attr


class LocateApps(object):
    """
    Proxies settings.app directly to django.apps
    """

    def __init__(self, app=None):
        self.__app = app

    def __getattr__(self, key):
        from django.apps import apps
        if self.__app:
            attr = apps.get_model(self.__app.label, key)
        else:
            conf = apps.get_app_config(key)
            attr = self.__class__(app=conf)
        # cache attr lookup
        setattr(self, key, attr)
        return attr

    def __dir__(self):
        from django.apps import apps
        if self.__app:
            # prefer object_name over model_name to match ClassNaming
            attrs = [
                model._meta.object_name
                for model in self.__app.get_models()
                if not model._meta.proxy
                ]
        else:
            attrs = [
                app.label
                for app in apps.get_app_configs()
                ]
        return attrs


class ConfigureApps(object):

    def __get__(self, settings, owner):
        if settings is None:
            return self

        import django
        from django.apps import apps
        from django.conf import settings as djsettings

        if not djsettings.configured:
            ns = utils.namespace(settings)
            djsettings.configure(**ns)
        if not apps.ready:
            django.setup()

        return LocateApps()

    def __set__(self, settings, value):
        raise AttributeError("can't set attribute")
